==> budget-rpc-0.3.0.2-sources.jar: com/chinayanghe/msp/budget/vo/budgetproject/out/BudgetProjectOutVo.java <==
/**
 * 2017
 * 上午11:20:33
 * 2017年6月6日
 * budget-rpc
 * com.chinayanghe.msp.budget.vo.budgetproject.out
 * BudgetProjectOutVo.java
 * BudgetProjectOutVo
 */
package com.chinayanghe.msp.budget.vo.budgetproject.out;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * QYX_BUD_INTF_0016	根据组织和经销商获取该组织下的预算维度信息
 * @author yangshuo
 *
 */
public class BudgetProjectOutVo implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = -9198612063303905666L;
	 private Integer id;

	    private String budgetAddressCode;

	    private Short budgetYear;

	    private String brandCode;

	    private String organizationCode;

	    private String budgetType;

	    private String kunnr;

	    private String costType;

	    private String channel;

	    private String extendWord1;

	    private String extendWord2;

	    private String extendWord3;

	    private String extendWord4;

	    private String extendWord5;

	    private String isNocheckBalance;

	    private Date canuseBeginDate;

	    private Date canuseEndDate;
	    /**
	     * 计划金额
	     */
	    private BigDecimal planMoney;

	    /**
	     * 下达金额
	     */
	    private BigDecimal isusedMoney;

	    /**
	     * 冻结金额
	     */
	    private BigDecimal frozenMoney;

	    /**
	     * 使用金额
	     */
	    private BigDecimal usedMoney;

	    private String createId;

	    private String createName;

	    private Date createDate;

	    private String modifyId;

	    private String modifyName;

	    private Date modifyDate;

	    public Integer getId() {
	        return id;
	    }

	    public void setId(Integer id) {
	        this.id = id;
	    }

	    public String getBudgetAddressCode() {
	        return budgetAddressCode;
	    }

	    public void setBudgetAddressCode(String budgetAddressCode) {
	        this.budgetAddressCode = budgetAddressCode == null ? null : budgetAddressCode.trim();
	    }

	    public Short getBudgetYear() {
	        return budgetYear;
	    }

	    public void setBudgetYear(Short budgetYear) {
	        this.budgetYear = budgetYear;
	    }

	    public String getBrandCode() {
	        return brandCode;
	    }

	    public void setBrandCode(String brandCode) {
	        this.brandCode = brandCode == null ? null : brandCode.trim();
	    }

	    public String getOrganizationCode() {
	        return organizationCode;
	    }

	    public void setOrganizationCode(String organizationCode) {
	        this.organizationCode = organizationCode == null ? null : organizationCode.trim();
	    }

	    public String getBudgetType() {
	        return budgetType;
	    }

	    public void setBudgetType(String budgetType) {
	        this.budgetType = budgetType == null ? null : budgetType.trim();
	    }

	    public String getKunnr() {
	        return kunnr;
	    }

	    public void setKunnr(String kunnr) {
	        this.kunnr = kunnr == null ? null : kunnr.trim();
	    }

	    public String getCostType() {
	        return costType;
	    }

	    public void setCostType(String costType) {
	        this.costType = costType == null ? null : costType.trim();
	    }

	    public String getChannel() {
	        return channel;
	    }

	    public void setChannel(String channel) {
	        this.channel = channel == null ? null : channel.trim();
	    }

	    public String getExtendWord1() {
	        return extendWord1;
	    }

	    public void setExtendWord1(String extendWord1) {
	        this.extendWord1 = extendWord1 == null ? null : extendWord1.trim();
	    }

	    public String getExtendWord2() {
	        return extendWord2;
	    }

	    public void setExtendWord2(String extendWord2) {
	        this.extendWord2 = extendWord2 == null ? null : extendWord2.trim();
	    }

	    public String getExtendWord3() {
	        return extendWord3;
	    }

	    public void setExtendWord3(String extendWord3) {
	        this.extendWord3 = extendWord3 == null ? null : extendWord3.trim();
	    }

	    public String getExtendWord4() {
	        return extendWord4;
	    }

	    public void setExtendWord4(String extendWord4) {
	        this.extendWord4 = extendWord4 == null ? null : extendWord4.trim();
	    }

	    public String getExtendWord5() {
	        return extendWord5;
	    }

	    public void setExtendWord5(String extendWord5) {
	        this.extendWord5 = extendWord5 == null ? null : extendWord5.trim();
	    }

	    public String getIsNocheckBalance() {
	        return isNocheckBalance;
	    }

	    public void setIsNocheckBalance(String isNocheckBalance) {
	        this.isNocheckBalance = isNocheckBalance == null ? null : isNocheckBalance.trim();
	    }

	    public Date getCanuseBeginDate() {
	        return canuseBeginDate;
	    }

	    public void setCanuseBeginDate(Date canuseBeginDate) {
	        this.canuseBeginDate = canuseBeginDate;
	    }

	    public Date getCanuseEndDate() {
	        return canuseEndDate;
	    }

	    public void setCanuseEndDate(Date canuseEndDate) {
	        this.canuseEndDate = canuseEndDate;
	    }

	    public BigDecimal getPlanMoney() {
	        return planMoney;
	    }

	    public void setPlanMoney(BigDecimal planMoney) {
	        this.planMoney = planMoney;
	    }

	    public BigDecimal getIsusedMoney() {
	        return isusedMoney;
	    }

	    public void setIsusedMoney(BigDecimal isusedMoney) {
	        this.isusedMoney = isusedMoney;
	    }

	    public BigDecimal getFrozenMoney() {
	        return frozenMoney;
	    }

	    public void setFrozenMoney(BigDecimal frozenMoney) {
	        this.frozenMoney = frozenMoney;
	    }

	    public BigDecimal getUsedMoney() {
	        return usedMoney;
	    }

	    public void setUsedMoney(BigDecimal usedMoney) {
	        this.usedMoney = usedMoney;
	    }

	    public String getCreateId() {
	        return createId;
	    }

	    public void setCreateId(String createId) {
	        this.createId = createId == null ? null : createId.trim();
	    }

	    public String getCreateName() {
	        return createName;
	    }

	    public void setCreateName(String createName) {
	        this.createName = createName == null ? null : createName.trim();
	    }

	    public Date getCreateDate() {
	        return createDate;
	    }

	    public void setCreateDate(Date createDate) {
	        this.createDate = createDate;
	    }

	    public String getModifyId() {
	        return modifyId;
	    }

	    public void setModifyId(String modifyId) {
	        this.modifyId = modifyId == null ? null : modifyId.trim();
	    }

	    public String getModifyName() {
	        return modifyName;
	    }

	    public void setModifyName(String modifyName) {
	        this.modifyName = modifyName == null ? null : modifyName.trim();
	    }

	    public Date getModifyDate() {
	        return modifyDate;
	    }

	    public void setModifyDate(Date modifyDate) {
	        this.modifyDate = modifyDate;
	    }
	}

==> budget-rpc-0.3.0.26-sources.jar: com/chinayanghe/msp/budget/vo/budgetproject/out/BudgetProjectOutVo.java <==
/**
 * 2017
 * 上午11:20:33
 * 2017年6月6日
 * budget-rpc
 * com.chinayanghe.msp.budget.vo.budgetproject.out
 * BudgetProjectOutVo.java
 * BudgetProjectOutVo
 */
package com.chinayanghe.msp.budget.vo.budgetproject.out;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * QYX_BUD_INTF_0016	根据组织和经销商获取该组织下的预算维度信息
 * @author yangshuo
 *
 */
public class BudgetProjectOutVo implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = -9198612063303905666L;
	 private Integer id;

	    private String budgetAddressCode;

	    private Short budgetYear;

	    private String brandCode;

	    private String organizationCode;

	    private String budgetType;

	    private String kunnr;

	    /**
	     * 费用类型编码
	     */
	    private String costType;
	    
	    /**
	     * 费用类型名字
	     */
	    private String costTypeName;

	    private String channel;

	    private String extendWord1;

	    private String extendWord2;

	    private String extendWord3;

	    private String extendWord4;

	    private String extendWord5;

	    private String isNocheckBalance;

	    private Date canuseBeginDate;

	    private Date canuseEndDate;
	    /**
	     * 计划金额
	     */
	    private BigDecimal planMoney;

	    /**
	     * 下达金额
	     */
	    private BigDecimal isusedMoney;

	    /**
	     * 冻结金额
	     */
	    private BigDecimal frozenMoney;

	    /**
	     * 使用金额
	     */
	    private BigDecimal usedMoney;

	    private String createId;

	    private String createName;

	    private Date createDate;

	    private String modifyId;

	    private String modifyName;

	    private Date modifyDate;

	    public Integer getId() {
	        return id;
	    }

	    public void setId(Integer id) {
	        this.id = id;
	    }

	    public String getBudgetAddressCode() {
	        return budgetAddressCode;
	    }

	    public void setBudgetAddressCode(String budgetAddressCode) {
	        this.budgetAddressCode = budgetAddressCode == null ? null : budgetAddressCode.trim();
	    }

	    public Short getBudgetYear() {
	        return budgetYear;
	    }

	    public void setBudgetYear(Short budgetYear) {
	        this.budgetYear = budgetYear;
	    }

	    public String getBrandCode() {
	        return brandCode;
	    }

	    public void setBrandCode(String brandCode) {
	        this.brandCode = brandCode == null ? null : brandCode.trim();
	    }

	    public String getOrganizationCode() {
	        return organizationCode;
	    }

	    public void setOrganizationCode(String organizationCode) {
	        this.organizationCode = organizationCode == null ? null : organizationCode.trim();
	    }

	    public String getBudgetType() {
	        return budgetType;
	    }

	    public void setBudgetType(String budgetType) {
	        this.budgetType = budgetType == null ? null : budgetType.trim();
	    }

	    public String getKunnr() {
	        return kunnr;
	    }

	    public void setKunnr(String kunnr) {
	        this.kunnr = kunnr == null ? null : kunnr.trim();
	    }

	    public String getCostType() {
	        return costType;
	    }

	    public void setCostType(String costType) {
	        this.costType = costType == null ? null : costType.trim();
	    }

	    public String getChannel() {
	        return channel;
	    }

	    public void setChannel(String channel) {
	        this.channel = channel == null ? null : channel.trim();
	    }

	    public String getExtendWord1() {
	        return extendWord1;
	    }

	    public void setExtendWord1(String extendWord1) {
	        this.extendWord1 = extendWord1 == null ? null : extendWord1.trim();
	    }

	    public String getExtendWord2() {
	        return extendWord2;
	    }

	    public void setExtendWord2(String extendWord2) {
	        this.extendWord2 = extendWord2 == null ? null : extendWord2.trim();
	    }

	    public String getExtendWord3() {
	        return extendWord3;
	    }

	    public void setExtendWord3(String extendWord3) {
	        this.extendWord3 = extendWord3 == null ? null : extendWord3.trim();
	    }

	    public String getExtendWord4() {
	        return extendWord4;
	    }

	    public void setExtendWord4(String extendWord4) {
	        this.extendWord4 = extendWord4 == null ? null : extendWord4.trim();
	    }

	    public String getExtendWord5() {
	        return extendWord5;
	    }

	    public void setExtendWord5(String extendWord5) {
	        this.extendWord5 = extendWord5 == null ? null : extendWord5.trim();
	    }

	    public String getIsNocheckBalance() {
	        return isNocheckBalance;
	    }

	    public void setIsNocheckBalance(String isNocheckBalance) {
	        this.isNocheckBalance = isNocheckBalance == null ? null : isNocheckBalance.trim();
	    }

	    public Date getCanuseBeginDate() {
	        return canuseBeginDate;
	    }

	    public void setCanuseBeginDate(Date canuseBeginDate) {
	        this.canuseBeginDate = canuseBeginDate;
	    }

	    public Date getCanuseEndDate() {
	        return canuseEndDate;
	    }

	    public void setCanuseEndDate(Date canuseEndDate) {
	        this.canuseEndDate = canuseEndDate;
	    }

	    public BigDecimal getPlanMoney() {
	        return planMoney;
	    }

	    public void setPlanMoney(BigDecimal planMoney) {
	        this.planMoney = planMoney;
	    }

	    public BigDecimal getIsusedMoney() {
	        return isusedMoney;
	    }

	    public void setIsusedMoney(BigDecimal isusedMoney) {
	        this.isusedMoney = isusedMoney;
	    }

	    public BigDecimal getFrozenMoney() {
	        return frozenMoney;
	    }

	    public void setFrozenMoney(BigDecimal frozenMoney) {
	        this.frozenMoney = frozenMoney;
	    }

	    public BigDecimal getUsedMoney() {
	        return usedMoney;
	    }

	    public void setUsedMoney(BigDecimal usedMoney) {
	        this.usedMoney = usedMoney;
	    }

	    public String getCreateId() {
	        return createId;
	    }

	    public void setCreateId(String createId) {
	        this.createId = createId == null ? null : createId.trim();
	    }

	    public String getCreateName() {
	        return createName;
	    }

	    public void setCreateName(String createName) {
	        this.createName = createName == null ? null : createName.trim();
	    }

	    public Date getCreateDate() {
	        return createDate;
	    }

	    public void setCreateDate(Date createDate) {
	        this.createDate = createDate;
	    }

	    public String getModifyId() {
	        return modifyId;
	    }

	    public void setModifyId(String modifyId) {
	        this.modifyId = modifyId == null ? null : modifyId.trim();
	    }

	    public String getModifyName() {
	        return modifyName;
	    }

	    public void setModifyName(String modifyName) {
	        this.modifyName = modifyName == null ? null : modifyName.trim();
	    }

	    public Date getModifyDate() {
	        return modifyDate;
	    }

	    public void setModifyDate(Date modifyDate) {
	        this.modifyDate = modifyDate;
	    }

		public String getCostTypeName() {
			return costTypeName;
		}

		public void setCostTypeName(String costTypeName) {
			this.costTypeName = costTypeName;
		}
	}
